(* $Id: term.mli 64 2003-08-24 15:39:25Z gerd $
 * ----------------------------------------------------------------------
 * Copyright 2003 by Gerd Stolpmann. 
 * 
 * This file is part of godi-tools. 
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
 *)

(* Interface to access and print terminal capabilities. If available,
 * terminfo is preferred, but it is also possible to use this library
 * with termcap, or even without terminal library.
 *
 * Without terminal library, "lines" and "columns" still return reasonable
 * values, but the get* functions always raise Not_found.
 *)

external setup : unit -> unit = "mlterm_setup";;
  (* Initializes this library *)

external lines : unit -> int = "mlterm_lines";;
  (* Returns the number of lines of the terminal. First, the environment
   * variable LINES is tried. If not set, the terminal capability is used.
   *)

external columns : unit -> int = "mlterm_columns";;
  (* Returns the number of columns of the terminal. First, the environment
   * variable COLUMNS is tried. If not set, the terminal capability is used.
   *)

external getflag : string -> string -> bool = "mlterm_getflag";;
  (* Returns the value of a boolean terminal capability.
   * The first string is the termcap name, the second string
   * is the terminfo name.
   * Raises Not_found if the capability is not available.
   *)

external getnum : string -> string -> int = "mlterm_getnum";;
  (* Returns the value of an integer terminal capability.
   * The first string is the termcap name, the second string
   * is the terminfo name.
   * Raises Not_found if the capability is not available.
   *)

external getstr : string -> string -> string = "mlterm_getstr";;
  (* Returns the value of a string terminal capability.
   * The first string is the termcap name, the second string
   * is the terminfo name.
   * The format of the returned string depends on the terminal
   * library. Use outputstr to print it to stdout.
   * Raises Not_found if the capability is not available.
   *)

external convert : string -> string = "mlterm_convertstr";;
  (* Calls tgets for the string, and returns the converted result.
   * This resolves notational abbreviations used in the terminal
   * description. Call [convert] for every string returned by
   * [getstr].
   *
   * Limitation: terminfo parameters cannot be instantiated.
   *)
